Furthermore, we can extend our findings to the generalised additive index regression, where a stochastic search algorithm is proposed to solve the problem.
This package contains a selection of functions for maximum likelihood
estimation of the generalised additive (and additive index) regression under shape constraints:
scar computes the maximum likelihood estimator
(specified via its value at the observed covariates). Output is a list of class
scar which is used as input to various auxiliary functions.
plot.scar produces plots of the maximum likelihood
estimator produced by scar on the scale of the additive predictors.
predict.scar obtains predictions either on the scale of the additive
predictors or on the scale of the response variable from a fitted scar object.
scair tries to find the maximum likelihood estimator
(specified via its value at the observed indices). Output is a list of class
scair which is used as input to various auxiliary functions.
plot.scair produces plots of the maximum likelihood
estimator produced by scair on the scale of the additive index predictors.
predict.scair obtains predictions either on the scale of the additive
index predictors or on the scale of the response variable from a fitted scair object.
The methods proposed here were applied to the following datasets:
PhDPublications, decathlon.
Hastie, T. and Tibshirani, R. (1990) Generalized Additive Models. Chapman and Hall, London.
Meyer, M. C. (2013) Semi-parametric Additive Constrained Regression. Journal of nonparametric statistics, 25, 715-743.
Nocedal, J., and Wright, S. J. (2006) Numerical Optimization, 2nd edition. Springer, New York.
Robertson, T., Wright, F. T. and Dykstra, R. L. (1988). Order Restricted Statistical Inference. Wiley, New York.
Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. Springer, New York.
Wood, S. N. (2004) Stable and efficient multiple smoothing parameter estimation for generalized additive models. Journal of American Statistical Association, 99, 673-686.
scar, scair,
Iso,
scam,
glm## See examples provided in functions scar and scairRun the code above in your browser using DataLab